
FIC.ergm = function(formula,XZeval,focus="logOR",position=NA,search="AllSubsets")
{
  # Y = response vector
  # X = regression variables that are present in all models, always included, explicitly include an intercept
  # if you want one to be present.
  # Z = regression variables to be used in the variable selection method 
  # XZeval = Values of X,Z variables for evaluating the FIC, default is all values of (X,Z)
  # outfile: name of the file where should the output should be written.
  # allsubsets: variable search amongst all possible subsets (default) OR
  # nested: only nested sequences, in the same order as given in the Z matrix (first column comes
  # first, then the second column is added, etc.

  pp = 1
  nn = length(c(as.matrix(eval(parse(text=sub("()","",formula[2]))))))
  
  set.seed(1)
  fit			= ergm(formula,estimate=c("MLE"),control=control.ergm(MCMLE.maxit = 15))
  betagamma.hat = fit$coef[-1]
  deltahat 		= nn^{1/2}*betagamma.hat

  J				= -fit$hessian
  invJ			= solve(-fit$hessian) 
    
  
  qq 			= length(fit$coef[-1])
    
  J00 = J[1:pp,1:pp]
  J11 = J[(pp+1):(pp+qq),(pp+1):(pp+qq)] 
  J10 = as.matrix(J[(pp+1):(pp+qq),1:pp])
  J01 = t(as.matrix(J[1:pp,(pp+1):(pp+qq)]))
  Q <- invJ[-(1:pp),-(1:pp)]

  if(search=="AllSubsets") varmatrix=combinations(qq)
  if(search=="Nested") {id=diag(qq); id[lower.tri(id)]=1; varmatrix=rbind(rep(0,qq),id)}
  n.eval = nrow(XZeval)
  
 X.eval=as.matrix(XZeval[,1])
 if (nrow(XZeval)>1){
 Z.eval=as.matrix(XZeval[,-1])}
 if (nrow(XZeval)==1){
 Z.eval=matrix(XZeval[,-1],nrow=1)}
 
 focus=focus
 position=position
    
funct<-function(k){
      res<-apply(varmatrix,1,FUN=function(x){FIC(focus,position,k,X.eval,Z.eval,J00,J10,x,Q=Q,omega=omega,deltahat=deltahat)})
      FIC.S<-unlist(sapply(res,"[",1))
	  MSE.S<-unlist(sapply(res,"[",2))
	  bias.S<-unlist(sapply(res,"[",3))
	  bias2.S<-unlist(sapply(res,"[",4))
	  var2.S<-unlist(sapply(res,"[",5))
	  var2.naive.S<-unlist(sapply(res,"[",6))
	  
return(list(FIC.S,MSE.S,bias.S,bias2.S,var2.S,var2.naive.S))}

 
FIC = function(focus,position,k,X.eval,Z.eval,J00,J10,variables,Q,omega,deltahat)
  {
  
	#print(k)
    x.chosen = c(X.eval[k,])
    z.chosen = Z.eval[k,]

	if (focus=="logOR")
	{
	partmutheta = as.vector(x.chosen)
    tau0sq = crossprod(partmutheta,solve(J00)%*%partmutheta)
    omega = (J10%*%solve(J00,x.chosen) - z.chosen)
    }  
	
	if (focus=="OR")
	{
	partmutheta = as.vector(x.chosen)
    tau0sq = crossprod(partmutheta,solve(J00)%*%partmutheta)
    omega = c(exp(c(X.eval[k,],Z.eval[k,])%*%(fit$coef)))*(J10%*%solve(J00,x.chosen) - z.chosen)
    }
	
	if (focus=="prob")
	{
	partmutheta = as.vector(x.chosen)
    tau0sq = crossprod(partmutheta,solve(J00)%*%partmutheta)
	pij=exp(c(X.eval[k,],Z.eval[k,])%*%(fit$coef))/(1+exp(c(X.eval[k,],Z.eval[k,])%*%(fit$coef)))
    omega = c(pij*(1-pij))*(J10%*%solve(J00,x.chosen) - z.chosen)
    } 
	
	if (focus=="gamma")
	{
	partmutheta = as.vector(x.chosen)
    tau0sq = crossprod(partmutheta,solve(J00)%*%partmutheta)
	e_ktheta=rep(0,length(x.chosen))
	e_kgamma=rep(0,length(z.chosen))
	e_kgamma[position]=1
	omega = (J10%*%solve(J00,e_ktheta)-e_kgamma)
    }  
	  
	if (focus=="theta")
	{
	partmutheta = as.vector(x.chosen)
    tau0sq = crossprod(partmutheta,solve(J00)%*%partmutheta)
	e_k=rep(0,length(x.chosen))
	e_k[position]=1
    omega = (J10%*%(solve(J00)%*%e_k))
    } 
	
	if (sum(variables)>0)
      {
        qq = length(variables)
        indic = variables*(1:qq)

        Id 		= diag (rep(1,qq))
        pi.S 	= matrix(Id[indic,],ncol=qq)

        Q.S  	= solve(pi.S %*% solve(Q ,t(pi.S)))
		Q0.S 	= crossprod(pi.S, Q.S) %*% pi.S
        G.S  	= Q0.S %*% solve(Q)

        
		bias2.S = max(t(omega)%*%(Id-G.S)%*%(tcrossprod(deltahat)-Q)%*%(Id-t(G.S))%*%omega,0) #PAGE 152
		bias.S = t(omega)%*%(Id-G.S)%*%deltahat 	#PAGE 152
		var2.S = tau0sq + crossprod(omega, Q0.S)%*%omega
		omega.S = pi.S %*% omega
        
		MSE.S   = var2.S + bias2.S #PAGE 152
		FIC.S	= MSE.S- (tau0sq-(crossprod(omega, Q)%*%omega))	#PAGE 152	
	  }
    else {
	FIC.S = crossprod(omega,deltahat)^2; #PAGE 147
	bias.S = crossprod(omega, deltahat);
	bias2.S = bias.S^2
	var2.S = tau0sq;
	MSE.S = var2.S+bias2.S; #PAGE 127
	}

    outputFIC=list(FIC.S,MSE.S,bias.S,bias2.S,var2.S)
    names(outputFIC)=c("FIC.S","MSE.S","bias.S","bias2.S","var2.S")
    return(outputFIC) 
  
  }
if (focus=="gamma"|focus=="theta"){ll<-funct(1)
FIC.subject.model=matrix(ll[[1]],nrow=1)
MSE.subject.model=matrix(ll[[2]],nrow=1)
bias.subject.model = matrix(ll[[3]],nrow=1)
bias2.subject.model = matrix(ll[[4]],nrow=1)
var.subject.model =  matrix(ll[[5]],nrow=1)
 }  else {  
ll<-sapply(1:n.eval,FUN=funct)
FIC.subject.model=do.call(rbind,ll[1,])
MSE.subject.model=do.call(rbind,ll[2,])
bias.subject.model = do.call(rbind,ll[3,])
bias2.subject.model = do.call(rbind,ll[4,])
var.subject.model =  do.call(rbind,ll[5,])}


# print(sum(FIC.subject.model<0))
# print(sum(MSE.subject.model<0))
# print(sum(bias2.subject.model<0))
# print(sum(var.subject.model<0))




colnms=paste("M",1:nrow(varmatrix),sep="")
colnames(FIC.subject.model)=colnms
colnames(MSE.subject.model)=colnms
colnames(bias.subject.model)=colnms
colnames(bias2.subject.model)=colnms
colnames(var.subject.model)=colnms

rownames(varmatrix)=colnms
colnames(varmatrix)=paste("Z",1:ncol(Z.eval),sep="")

FIC.minima = apply(FIC.subject.model,1,which.min)
which.vars.selected = varmatrix[FIC.minima,]
return(list(FIC=FIC.subject.model,MSE=MSE.subject.model,Bias=bias.subject.model,Bias2=bias2.subject.model,
Var=var.subject.model,SelectedVars = which.vars.selected,Delta=fit$coef,varmatrix=varmatrix))
} 


FIC.ergm.summary=function(FICscores,SizeUnprotected,focus="logOR",search="AllSubsets")
{

  # Equal weight to all covariate combinations for model estimation
  FIC.eq.weighted = apply(FICscores,2,mean)

  if(search=="AllSubsets") varmatrix=combinations(SizeUnprotected)
  if(search=="Nested") {id=diag(SizeUnprotected); id[lower.tri(id)]=1; varmatrix=rbind(rep(0,SizeUnprotected),id)}

  print("Global model selection via FIC")
  print(paste("Focus = ",focus))
  print("All focuses equal weight")
  print("")
  print("Variables in the selected model:")
  print(varmatrix[which.min(FIC.eq.weighted),])

  print("Average FIC values for all models:")
  print(FIC.eq.weighted)

  print("Model number:")
  print(which.min(FIC.eq.weighted))
  return(list(SelectedVars=varmatrix[which.min(FIC.eq.weighted),], Model=which.min(FIC.eq.weighted)))

}

