% file SocNetFIC/man/FIC.ergm.Rd
% copyright (C) XXXX
%
\name{FIC.ergm}
\alias{FIC.ergm}
\title{
Estimate Bias, Variance, MSE and FIC for a given focus and a collection of plausible models under ERGM.
}
\description{
For each of the models, for a predefined focus, the function estimates the bias and variance of the 
estimator of the focus. Based on these two quantities MSE and FIC expressions are calculated and
the model with the best performance (i.e. lowest FIC) is selected.  
}
\usage{
FIC.ergm(formula,XZeval,focus="logOR",position=NA,search="AllSubsets")}
\arguments{
\item{formula}{
A generic \code{formula} object of the form network ~ ergm.summary_1 + ... + ergm.summary_p.
}
\item{XZeval}{
Matrix of size k x p where each column corresponds to evaluation point for each of the p predictors. There are k different evaluation points. 
}
\item{focus}{
The focus parameters. Can be either "\code{logOR}" (default), "\code{OR}", "\code{prob}", "\code{\gamma}", or "\code{\theta}". 
}
\item{search}{
Can be either "\code{AllSubsets}" (default) or "\code{Nested}". If "\code{search==AllSubsets}" then an all subsets search among all possible models is 
performed and if "\code{search==Nested}" then only incremental/nested models are allowed.  
}
}
\value{
A list containing the objects:

\item{FIC}{
The FIC scores for each model.
}
\item{MSE}{
The MSE scores for each model.
}
\item{Bias}{
The Bias values of the focus estimator in each model.
}
\item{Bias2}{
The Squared Bias values of the focus estimator in each model.
}
\item{Var}{
The Variance values of the focus estimator in each model.
}
\item{SelectedVars}{
The final selected variables.
}
\item{Delta}{
Estimated \delta (neighborhood deviation) values.
}
\item{varmatrix}{Model definition in terms of included/excluded variables }
}


\examples{
library(ergm)
data(florentine)
data(flo)
fam_wealth					= flomarriage \%v\% "wealth"
flomarriage \%v\% "wealth"		= log(fam_wealth)
formula 					= flomarriage  ~ kstar(1)+kstar(2)+kstar(3)+triangle+gwesp(alpha = 0.5,fixed=T)+absdiff("wealth",pow=1)
XZeval 						= rbind(c(2,10,21,1,2.393469,0.3488776),c( -2,-5,-4,-2,-5.393469,-1.091786))
obj1 						= FIC.ergm(formula,XZeval,focus="logOR")
obj1
obj2						= FIC.ergm(formula,XZeval,focus="OR") 
obj2
obj3						= FIC.ergm(formula,XZeval,focus="prob") 
obj3
obj4						= FIC.ergm(formula,XZeval,focus="gamma", position=3) 
obj4
}
\keyword{algebra}
