% file SocNetFIC/man/FIC.ergm.summary.Rd
% copyright (C) XXXX
%
\name{FIC.ergm.summary}
\alias{FIC.ergm.summary}
\title{
Estimate the model that performs best with respect to several focuses given a collection of plausible models.
}
\description{
For each of the models, for a predefined focus, the function estimates the bias and variance of the 
estimator of the focus. Based on these two quantities MSE and FIC expressions are calculated and
the model with the best performance (i.e. lowest FIC) is selected.  
}
\usage{
FIC.ergm.summary(FICscores,SizeUnprotected,focus="logOR",search="AllSubsets")}
\arguments{
\item{FICscores}{
A generic matrix containing the FIC scores for the tested models for k different evaluation points.
}
\item{SizeUnprotected}{
Length of the vector of unprotected parameters
}
\item{focus}{
The focus parameters. Can be either "\code{logOR}" (default), "\code{OR}", "\code{prob}", "\code{\gamma}", or "\code{\theta}". 
}
\item{search}{
Can be either "\code{AllSubsets}" (default) or "\code{Nested}". If "\code{search==AllSubsets}" then an all subsets search among all possible models is 
performed and if "\code{search==Nested}" then only incremental/nested models are allowed.  
}
}
\value{
A list containing the objects:


\item{SelectedVars}{
The final selected variables when the model that performs best with respect to all focuses is desired.
}

\item{Model}{The model number}
}


\examples{
library(ergm)
data(florentine)
data(flo)
fam_wealth					= flomarriage \%v\% "wealth"
flomarriage \%v\% "wealth"		= log(fam_wealth)
formula 					= flomarriage  ~ kstar(1)+kstar(2)+kstar(3)+triangle+gwesp(alpha = 0.5,fixed=T)+absdiff("wealth",pow=1)
XZeval 						= rbind(c(2,10,21,1,2.393469,0.3488776),c( -2,-5,-4,-2,-5.393469,-1.091786))
obj1 						= FIC.ergm(formula,XZeval,focus="logOR")
obj1
obj2						= FIC.ergm.summary(FICscores=obj1$FIC,SizeUnprotected=5,focus="logOR",search="AllSubsets")	
obj2
}

\keyword{algebra}
