% file SocNetFIC/man/FIC.nam.Rd
% copyright (C) XXXX
%
\name{FIC.nam}
\alias{FIC.nam}
\title{
Estimate Bias, Variance, MSE and FIC for a given focus and a collectnam of plausible models under Network Autocorrelation Models.
}
\description{
For each of the models, for a predefined focus, the functnam estimates the bias and variance of the 
estimator of the focus. Based on these two quantities MSE and FIC expressnams are calculated and
the model with the best performance (i.e. lowest FIC) is selected.  
}
\usage{
FIC.nam(Y,X,Z,W1=NULL,W2=NULL,focus="E(Y|x,z)",protected,unprotected,varmatrix)}
\arguments{
\item{Y}{A response variable.}
\item{X}{Variables that are present in all models, always included, explicitly include an intercept if desired}
\item{W1}{Autoregressive network}
\item{W2}{Autocorrelatnam network}
\item{focus}{The focus parameter. Can be either "\code{E(Y|x,z)}" (default), "\code{Rho1}" or "\code{Rho2}".}
\item{protected}{Vector of names corresponding to the protected parameters}
\item{unprotected}{Vector of names corresponding to the unprotected parameters}
\item{varmatrix}{Parameter matrix, where 1/0 correponds to a parameter being included/excluded in the model}
}
\value{
A list containing the objects:

\item{FIC}{The FIC scores for each model.}
\item{MSE}{The MSE scores for each model.}
\item{Bias}{The Bias values of the focus estimator in each model.}
\item{Bias2}{The Squared Bias values of the focus estimator in each model.}
\item{Var}{The Variance values of the focus estimator in each model.}
\item{SelectedVars}{The final selected variables.}
\item{Delta}{Estimated \delta (neighborhood deviatnam) values}
\item{Rho1}{Network autoregressive coefficient.}
\item{Rho2}{Network autocorrelatnam coefficient.}
}


\examples{
library(ergm)
library(sna)
data(florentine)
data(flo)
wealth 		= flomarriage \%v\% "wealth"
priorates 	= flomarriage \%v\% "priorates"
totalties 	= flomarriage \%v\% "totalties"
W1 		= as.matrix(flobusiness)
W2 		= as.matrix(flomarriage)
Y 		= log(wealth)
X 		= matrix(rep(1,length(Y)),ncol=1)
Z 		= cbind(priorates,totalties,degree(W2),rowMeans(cbind(betweenness(W1),betweenness(W2))),rowMeans(cbind(flowbet(W1),flowbet(W2))))
colnames(X) 	= "Intercept"
colnames(Z) 	= c("Priorates","Totalties","Degree","Betweenness","FlowBetweenness")
protected 	= c("SigSq","Intercept")
unprotected 	= c("Rho1","Rho2","Priorates","Totalties","Degree","Betweenness","FlowBetweenness") 
varmatrix 	= allsubsets.varmatrix(unprotected)
obj1 		= FIC.nam(Y,X,Z,W1,W2,focus="E(Y|x,z)",protected,unprotected,varmatrix)
obj1		
obj2 		= FIC.nam(Y,X,Z,W1,W2,focus="Rho1",protected,unprotected,varmatrix)
obj2		
obj3 		= FIC.nam(Y,X,Z,W1,W2,focus="Rho2",protected,unprotected,varmatrix)
obj3

}
\keyword{}
