% file SocNetFIC/man/FIC.nam.summary.Rd
% copyright (C) XXXX
%
\name{FIC.nam.summary}
\alias{FIC.nam.summary}
\title{
Estimate the model that performs best with respect to several focuses given a collection of plausible models.
}
\description{
For each of the models, for a predefined focus, the function estimates the bias and variance of the 
estimator of the focus. Based on these two quantities MSE and FIC expressions are calculated and
the model with the best performance (i.e. lowest FIC) is selected.  
}
\usage{
FIC.nam.summary(FICscores,varmatrix,focus)}
\arguments{
\item{FICscores}{A generic matrix containing the FIC scores for the tested models for k different evaluation points.}
\item{varmatrix}{Parameter matrix, where 1/0 correponds to a parameter being included/excluded in the model}
\item{focus}{The focus parameter. Can be either "\code{E(Y|x,z)}" (default), "\code{Rho1}" or "\code{Rho2}".}
}
\value{
A list containing the objects: 

\item{SelectedVars}{The final selected variables when the model that performs best with respect to all focuses is desired.}
\item{Model}{The model number}
}


\examples{
library(ergm)
library(sna)
data(florentine)
data(flo)
wealth 		= flomarriage \%v\% "wealth"
priorates 	= flomarriage \%v\% "priorates"
totalties 	= flomarriage \%v\% "totalties"
W1 		= as.matrix(flobusiness)
W2 		= as.matrix(flomarriage)
Y 		= log(wealth)
X 		= matrix(rep(1,length(Y)),ncol=1)
Z 		= cbind(priorates,totalties,degree(W2),rowMeans(cbind(betweenness(W1),betweenness(W2))),rowMeans(cbind(flowbet(W1),flowbet(W2))))
colnames(X) 	= "Intercept"
colnames(Z) 	= c("Priorates","Totalties","Degree","Betweenness","FlowBetweenness")
protected 	= c("SigSq","Intercept")
unprotected 	= c("Rho1","Rho2","Priorates","Totalties","Degree","Betweenness","FlowBetweenness") 
varmatrix 	= allsubsets.varmatrix(unprotected)
obj1 		= FIC.nam(Y,X,Z,W1,W2,focus="E(Y|x,z)",protected,unprotected,varmatrix)
obj2 		= FIC.nam.summary(obj1$FIC,allsubsets.varmatrix(unprotected),focus="E(Y|x,z)")
}

\keyword{algebra}
