% file SocNetFIC/man/FIC.nrm.Rd
% copyright (C) XXXX
%
\name{FIC.nrm}
\alias{FIC.nrm}
\title{
Estimate Bias, Variance, MSE and FIC for a given focus and a collection of plausible models under Network Regression Models.
}
\description{
For each of the models, for a predefined focus, the function estimates the bias and variance of the 
estimator of the focus. Based on these two quantities MSE and FIC expressions are calculated and
the model with the best performance (i.e. lowest FIC) is selected.  
}
\usage{
FIC.nrm(Y,X,Z,W2=NULL,focus="E(Y|x,z)",protected,unprotected,varmatrix)}
\arguments{
\item{Y}{A response network object}
\item{X}{Network that is present in all models}
\item{Z}{Networks to be used in the variable selection method}
\item{W2}{Autocorrelation network}
\item{focus}{The focus parameter. Can be either "\code{E(Y|x,z)}" (default) or "\code{Prestige}".}
\item{protected}{Vector of names corresponding to the protected parameters}
\item{unprotected}{Vector of names corresponding to the unprotected parameters}
\item{varmatrix}{Parameter matrix, where 1/0 correponds to a parameter being included/excluded in the model}
\item{actor}{If the focus is \code{Prestige}, then for which actor in the network}
}
\value{
A list containing the objects:

\item{FIC}{The FIC scores for each model.}
\item{MSE}{The MSE scores for each model.}
\item{Bias}{The Bias values of the focus estimator in each model.}
\item{Bias2}{The Squared Bias values of the focus estimator in each model.}
\item{Var}{The Variance values of the focus estimator in each model.}
\item{SelectedVars}{The final selected variables.}
\item{Delta}{Estimated \delta (neighborhood deviation) values}
\item{Rho2}{Network autocorrelation coefficient.}
}


\examples{
library(sna)
data(Sampson)
Y		= exitmat
X		= matrix(1,dim(Y)[1],dim(Y)[2])
diag(X)		= 0
liking		= liking1+liking2+liking3
liking[liking >0]=1 
Z		= list(liking+t(liking),esteem+t(esteem),pinfluence+t(pinfluence),praise+t(praise),disliking+t(disliking),desteem+t(desteem),ninfluence+t(ninfluence),blame+t(blame))
for (i in 1: 8)
	{
	Z[[i]][Z[[i]]>0]=1
	}
protected	= c("SigSq","Intercept")
unprotected	= c("liking","esteem","pinfluence","praise","disliking","desteem","ninfluence","blame")  
varmatrix	= allsubsets.varmatrix(unprotected)
names(Z)	= c("liking","esteem","pinfluence","praise","disliking","desteem","ninfluence","blame") 
obj1		= FIC.nrm(Y,X,Z,W2=NULL,focus="E(Y|x,z)",protected,unprotected,varmatrix)
obj1		
obj2		= FIC.nrm(Y,X,Z,W2=NULL,focus="Prestige",protected,unprotected,varmatrix)
obj2		
}
\keyword{}
